@@ -1,6 +1,6 @@
-use std::collections::{HashMap};
-use std::{fs};
-use std::{path::Path};
+use std::collections::HashMap;
+use std::fs;
+use std::path::Path;
 use std::path::PathBuf;
 
 use serde::{Serialize, Deserialize};
@@ -36,7 +36,8 @@ pub enum DataValue {
     String(String),
     Number(f64),
     Boolean(bool),
-    Dict(HashMap<String,String>)
+    Dict(HashMap<String,String>),
+    ByteVector(Vec<u8>),
 }
 
 #[derive(Debug,Clone)]
@@ -50,10 +51,9 @@ pub struct DataBase {
 #[derive(Debug)]
 pub struct DataBaseManager {
     db_list: HashMap<String,DataBase>,
-    root_path: String,
+    pub root_path: String,
     config: Option<toml::Value>,
     pub cache_eliminate: crate::structure::LRU,
-    pub current_db: String,
 }
 
 // ---- config struct ---- //
@@ -99,23 +99,27 @@ pub struct InsertOptions {
 impl DataBaseManager {
 
     // create new DataBase Manager
-    pub fn new(root: &'static str) -> Self {
+    pub fn new() -> Self {
+
+        let path  = match dirs::data_local_dir() {
+            Some(v) => v,
+            None => PathBuf::from("./")
+        };
+
+        let root_path = path.join("Dorea");
+        let root_path = root_path.to_str().unwrap();
+        let root = root_path.to_string();
+
         let mut object = DataBaseManager {
             db_list: HashMap::new(),
             root_path: root.to_string(),
             config: None,
             cache_eliminate: LRU::new(),
-            current_db: "default".to_string(),
         };
 
         let config = object.load_config();
         object.config = Some(config.clone());
 
-        match &config["database"].get("default_database") {
-            None => { /* default */ }
-            Some(val) => { object.current_db = val.as_str().unwrap().to_string(); }
-        }
-
         object
     }
 
@@ -123,12 +127,12 @@ impl DataBaseManager {
 
         let config = self.config.as_ref().unwrap();
 
-        let expire = option.expire.clone();
-        let unlocal_sign = option.unlocal_sign.clone();
+        let expire = option.expire;
+        let unlocal_sign = option.unlocal_sign;
 
 
         let max_mem = match config["memory"].get("maximum_memory_cache") {
-            None => 120,
+            None => 512,
             Some(max) => max.as_integer().unwrap(),
         };
 
@@ -214,7 +218,7 @@ impl DataBaseManager {
 
     pub fn clean(&mut self, db: &str) -> crate::Result<()> {
 
-        let config = self.config.as_ref().unwrap();
+        // let config = self.config.as_ref().unwrap();
 
         if self.db_list.contains_key(db) {
             self.db_list.remove(db);
@@ -222,15 +226,6 @@ impl DataBaseManager {
 
         // if current db eq clean db
         // change current to default db
-        if &self.current_db == db {
-            let default = config["database"].get("default_database");
-            let default = match default {
-                None => "name",
-                Some(val) => val.as_str().unwrap(),
-            };
-            self.current_db = default.to_string();
-        }
-
         self.cache_eliminate.clean(&db.to_string());
 
         let path = Path::new(&self.root_path).join("storage");
@@ -238,9 +233,19 @@ impl DataBaseManager {
 
         log::info!("@{} clean all value.",db);
 
+        let c_path = Path::new(&self.root_path).join("storage");
+        let c_path = c_path.join(format!("~@{}",db));
+
         if path.is_dir() {
-            return match fs::remove_dir_all(path) {
-                Ok(_) => { Ok(()) }
+            return match fs::rename(&path,&c_path) {
+                Ok(_) => {
+                    tokio::task::spawn(async move {
+                        if let Err(e) = fs::remove_dir_all(c_path) {
+                            log::error!("{}",e);
+                        }
+                    });
+                    Ok(())
+                }
                 Err(_) => {
                     Err("clean failure".to_string())
                 }
@@ -482,18 +487,18 @@ impl DataBase {
 
         let size = value.sizeof();
         self.data.insert(key.clone(),DataNode {
-            key: key.clone(),
+            key: key.to_string(),
             value: value.clone(),
             value_size: size,
             expire_stamp: expire,
-            database: db_name.clone()
+            database: db_name.to_string()
         });
 
         // if update, do not save to local file.
         if !self.exist(key.clone()) {
 
             self.save_to_local(key.clone(),DataNode {
-                key: key.clone(),
+                key: key.to_string(),
                 value: value.clone(),
                 value_size: value.sizeof(),
                 expire_stamp: 0,
@@ -629,6 +634,7 @@ impl DataValue {
             DataValue::Number(val) => val.clone() as usize,
             DataValue::Boolean(_) => 1,
             DataValue::Dict(val) => val.len(),
+            DataValue::ByteVector(val) => val.len(),
         };
 
         res
